@@ -32,6 +32,9 @@
 #define USE_PROTOCOL_1 0
 
 #include "nuclient.h"
+
+#include <config.h>
+
 #include <sasl/saslutil.h>
 #include <proto.h>
 #include <jhash.h>
@@ -63,6 +66,8 @@ int conn_on;
 int recv_started;
 int timestamp_last_sent;
 
+
+
 /* callbacks we support */
 int nu_getrealm(void *context __attribute__((unused)), int id,
 		const char **availrealms __attribute__((unused)),
@@ -165,6 +170,7 @@ static void nu_exit_clean(NuAuth * session)
 		if (session->tls){
 			gnutls_bye(*(session->tls),GNUTLS_SHUT_RDWR);
 			gnutls_deinit(*(session->tls));
+			gnutls_certificate_free_credentials (session->cred);
 			free(session->tls);
 		}
 		if (session->socket>0){
@@ -174,14 +180,15 @@ static void nu_exit_clean(NuAuth * session)
 		if (session->username){
 			free(session->username);
 		}
+		if (session->ct){
+			tcptable_free(session->ct);
+		}
 		if (session->password){
 			free(session->password);
 		}
 		free(session);
 		session=NULL;
 	}
-	sasl_done();
-	gnutls_global_deinit();	
 }
 
 static void recv_message(NuAuth* session){
@@ -263,6 +270,10 @@ static int tcptable_add (conntable_t *ct, conn_t *c)
 		panic ("memory exhausted");	
 	}
 
+#ifdef	UDP_AUTH_ENABLE
+  	c->createtime=time(NULL);
+#endif
+
 	memcpy (newc, c, sizeof (conn_t));
 	bi = tcptable_hash (c);
 	old = ct->buckets[bi];
@@ -307,6 +318,9 @@ static conn_t* tcptable_find (conntable_t *ct, conn_t *c)
 static int tcptable_read (NuAuth* session, conntable_t *ct)
 {
 	static FILE *fp = NULL;
+#ifdef	UDP_AUTH_ENABLE
+	static FILE *fq = NULL;
+#endif
 	char buf[1024];
 	conn_t c;
 #if DEBUG
@@ -339,8 +353,6 @@ static int tcptable_read (NuAuth* session, conntable_t *ct)
 		// Check if there is a matching rule in the filters list
 		printf("Packet dst = %ld (%lx)\n", c.rmt, c.rmt);
 #endif
-		if ((c.ino == 0) || (st != TCP_SYN_SENT))
-			continue;
 		/* Check if it's the good user */
 		if (c.uid != session->localuserid)
 			continue;
@@ -350,10 +362,62 @@ static int tcptable_read (NuAuth* session, conntable_t *ct)
 			continue;
 		if (!session->auth_by_default && !seen)
 			continue;
+#ifdef	UDP_AUTH_ENABLE
+                c.proto=IPPROTO_TCP;
+#endif
 		if (tcptable_add (ct, &c) == 0)
 			return 0;
 	}
 
+#ifdef	UDP_AUTH_ENABLE
+ /* open file */
+	if (fq == NULL) {
+		fq = fopen ("/proc/net/udp", "r");
+		if (fq == NULL) panic ("/proc/net/udp: %s", strerror (errno));
+	}
+	rewind (fq);
+
+	if (fgets (buf, sizeof (buf), fq) == NULL)
+		panic ("/proc/net/udp: missing header");
+
+	while (fgets (buf, sizeof (buf), fq) != NULL) {
+		unsigned long st;
+#if USE_FILTER
+		int seen = 0;
+#endif
+		if (sscanf (buf, "%*d: %lx:%x %lx:%x %lx %*x:%*x %*x:%*x %x %lu %*d %lu",
+					&c.lcl, &c.lclp, &c.rmt, &c.rmtp, &st, &c.retransmit, &c.uid, &c.ino) != 8)
+			continue;
+
+		if (c.ino == 0) 
+			continue;
+
+		// Check if it's the good user
+		if (c.uid != session->localuserid)
+			continue;
+#if DEBUG
+		// Check if there is a matching rule in the filters list
+		printf("Packet dst = %ld (%lx)\n", c.rmt, c.rmt);
+#endif
+		/* Check if it's the good user */
+		if (c.uid != session->localuserid)
+			continue;
+#if USE_FILTER
+		// If we're sure auth_by_default is either 0 or 1, it can be simplified.
+		// (MiKael) TODO: Make sure!! :)
+		if (session->auth_by_default && seen)
+			continue;
+		if (!session->auth_by_default && !seen)
+			continue;
+#endif
+                c.proto=IPPROTO_UDP;
+		if (tcptable_add (ct, &c) == 0)
+			return 0;
+	}
+
+#endif
+
+
 	return 1;
 }
 
@@ -482,7 +546,6 @@ int mysasl_negotiate(gnutls_session session, sasl_conn_t *conn)
 
 static int send_hello_pckt(NuAuth * session){
 	struct nuv2_header header;
-	uint16_t header_length;
 
 	/* fill struct */
 	header.proto=0x2;
@@ -549,7 +612,11 @@ static int send_user_pckt(NuAuth * session,conn_t* c)
 				authfield.src=htonl(c->lcl);
 				authfield.dst=htonl(c->rmt);
 #endif
-				authfield.proto=6;
+#ifdef	UDP_AUTH_ENABLE
+				authfield.proto=c->proto;
+#else
+				authfield.proto=IPPROTO_TCP;
+#endif
 				authfield.flags=0;
 				authfield.FUSE=0;
 #ifdef WORDS_BIGENDIAN	
@@ -681,6 +748,22 @@ static int compare (NuAuth * session,conntable_t *old, conntable_t *new)
 						return -1;
 					}
 				}
+
+#ifdef	UDP_AUTH_ENABLE
+              /* solve timeout issue on UDP */
+              if (bucket->proto == IPPROTO_UDP){
+                  /* send an auth packet if netfilter timeout may have been reached */
+                  if (same_bucket->createtime<time(NULL)-UDP_TIMEOUT){
+			if (send_user_pckt (session,bucket) != 1){
+						/* error sending */
+						return -1;
+					}
+                  } else {
+                      bucket->createtime=same_bucket->createtime;
+                  }
+              }
+#endif
+
 			}
 			bucket = bucket->next;
 		}
@@ -714,7 +797,6 @@ static int generate_dh_params(void) {
 NuAuth* nu_client_init(char *username, unsigned long userid, char *password,
 		const char *hostname, unsigned int port, char protocol, char ssl_on)
 {
-	gnutls_certificate_credentials xcred;
 	conntable_t *new;
 	int ret;
 #if 0
@@ -808,24 +890,24 @@ NuAuth* nu_client_init(char *username, unsigned long userid, char *password,
 
 
 
-		gcry_control (GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
-		gnutls_global_init();
 		session->tls=(gnutls_session *)calloc(1,sizeof(gnutls_session));
 		/* X509 stuff */
-		gnutls_certificate_allocate_credentials(&xcred);
+		gnutls_certificate_allocate_credentials(&(session->cred));
 		/* sets the trusted cas file
 		*/
-		gnutls_certificate_set_x509_trust_file(xcred, certfile, GNUTLS_X509_FMT_PEM);
+		if (certfile[0]){
+			gnutls_certificate_set_x509_trust_file(session->cred, certfile, GNUTLS_X509_FMT_PEM);
+		}
 
 		if ( certfile[0] && keyfile[0]){
-		ret = gnutls_certificate_set_x509_key_file(xcred, certfile, keyfile, GNUTLS_X509_FMT_PEM);
-		if (ret <0){
-			printf("problem with X509 file : %s\n",gnutls_strerror(ret));
-		}
+			ret = gnutls_certificate_set_x509_key_file(session->cred, certfile, keyfile, GNUTLS_X509_FMT_PEM);
+			if (ret <0){
+				printf("problem with X509 file : %s\n",gnutls_strerror(ret));
+			}
 		}
 
 		generate_dh_params();
-		gnutls_certificate_set_dh_params( xcred, dh_params);
+		gnutls_certificate_set_dh_params( session->cred, dh_params);
 
 
 		/* Initialize TLS session 
@@ -838,7 +920,7 @@ NuAuth* nu_client_init(char *username, unsigned long userid, char *password,
 		gnutls_certificate_type_set_priority(*(session->tls), cert_type_priority);
 #endif
 		/* put the x509 credentials to the current session */
-		gnutls_credentials_set(*(session->tls), GNUTLS_CRD_CERTIFICATE, xcred);
+		gnutls_credentials_set(*(session->tls), GNUTLS_CRD_CERTIFICATE, session->cred);
 
 
 
@@ -876,21 +958,9 @@ NuAuth* nu_client_init(char *username, unsigned long userid, char *password,
 			printf("Server Certificat OK\n");
 		}
 
-		printf("maman\n");
-
 		/* SASL time */
 
-		/* initialize the sasl library */
-		ret = sasl_client_init(callbacks);
-		if (ret != SASL_OK) {
-			nu_exit_clean(session);
-			errno=EAGAIN;
-			return NULL;
-		}
-
-		/* client new connection */
-		//   ret = sasl_client_new(service, host, localaddr, remoteaddr, NULL, 0, &conn);
-		ret = sasl_client_new("NuFW", "myserver", NULL, NULL, NULL, 0, &conn);
+		ret = sasl_client_new("NuFW", "myserver", NULL, NULL, callbacks, 0, &conn);
 		if (ret != SASL_OK) {
 			printf("Failed allocating connection state");
 			nu_exit_clean(session);
@@ -1049,13 +1119,38 @@ void nu_client_free(NuAuth *session)
 	nu_exit_clean(session);
 }
 
+
+
+
+/**
+ * global init 
+ *
+ * to be called once
+ */
+ 
+void nu_client_global_init()
+{
+	gcry_control (GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
+	gnutls_global_init();
+}
+
+/**
+ * global de init 
+ *
+ * to be called once when leaving
+ */
+ 
+void nu_client_global_deinit()
+{
+        gnutls_global_deinit();
+}
+
 NuAuth* nu_client_init2(
 		const char *hostname, unsigned int port,
 		char* keyfile, char* certfile,
 		void* username_callback,void * passwd_callback, void* tlscred_callback
 		)
 {
-	gnutls_certificate_credentials xcred;
 	conntable_t *new;
 	int ret;
 	int option_value;
@@ -1065,21 +1160,22 @@ NuAuth* nu_client_init2(
 	sasl_conn_t *conn;
 	NuAuth * session;
 	struct sigaction no_action;
-
-	session=(NuAuth*) calloc(1,sizeof(NuAuth));
+	char certstring[256];
+        char keystring[256];
+        
+        session=(NuAuth*) calloc(1,sizeof(NuAuth));
 	session->username_callback=username_callback;
 	session->passwd_callback=passwd_callback;
 	session->tls_passwd_callback=tlscred_callback;
 
-	sasl_callback_t callbacks[] = {
+
+        sasl_callback_t callbacks[] = {
 		{ SASL_CB_GETREALM, &nu_getrealm, session }, 
 		{ SASL_CB_USER, &nu_get_userdatas, session }, 
 		{ SASL_CB_AUTHNAME, &nu_get_userdatas, session } , 
 		{ SASL_CB_PASS, &nu_get_usersecret, session },
 		{ SASL_CB_LIST_END, NULL, NULL }
-	};
-
-
+        };
 
 	/* initiate session */
 	session->auth_by_default = 1;
@@ -1107,8 +1203,9 @@ NuAuth* nu_client_init2(
 	}
 	/* compute patch keyfile */
 	if (! keyfile){
-		keyfile=calloc(256,1);
+		keyfile=keystring;
 		snprintf(keyfile,255,"%s/.nufw/key.pem",getenv("HOME"));
+		keyfile[255]=0;
 	}
 	/* test if key exists */
 	if (access(keyfile,R_OK)){
@@ -1120,8 +1217,9 @@ NuAuth* nu_client_init2(
 	}
 
 	if (! certfile){
-		certfile=calloc(256,1);
+		certfile=certstring;
 		snprintf(certfile,255,"%s/.nufw/cert.pem",getenv("HOME"));
+		certfile[255]=0;
 	}
 	/* test if cert exists */
 	if (access(certfile,R_OK)){
@@ -1132,24 +1230,22 @@ NuAuth* nu_client_init2(
 #endif
 	}
 
-	gcry_control (GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
-	gnutls_global_init();
 	session->tls=(gnutls_session *)calloc(1,sizeof(gnutls_session));
 	/* X509 stuff */
-	gnutls_certificate_allocate_credentials(&xcred);
+	gnutls_certificate_allocate_credentials(&(session->cred));
 	/* sets the trusted cas file
 	*/
 #if REQUEST_CERT
-	gnutls_certificate_set_x509_trust_file(xcred, certfile, GNUTLS_X509_FMT_PEM);
+	gnutls_certificate_set_x509_trust_file(session->cred, certfile, GNUTLS_X509_FMT_PEM);
 #endif
         if (certfile && keyfile){
-            ret = gnutls_certificate_set_x509_key_file(xcred, certfile, keyfile, GNUTLS_X509_FMT_PEM);
+		ret = gnutls_certificate_set_x509_key_file(session->cred, certfile, keyfile, GNUTLS_X509_FMT_PEM);
             if (ret <0){
                 printf("problem with keyfile : %s\n",gnutls_strerror(ret));
             }
         }
 	generate_dh_params();
-	gnutls_certificate_set_dh_params( xcred, dh_params);
+	gnutls_certificate_set_dh_params( session->cred, dh_params);
 
 
 	/* Initialize TLS session 
@@ -1160,7 +1256,7 @@ NuAuth* nu_client_init2(
 	gnutls_set_default_priority(*(session->tls));
 	gnutls_certificate_type_set_priority(*(session->tls), cert_type_priority);
 	/* put the x509 credentials to the current session */
-	gnutls_credentials_set(*(session->tls), GNUTLS_CRD_CERTIFICATE, xcred);
+	gnutls_credentials_set(*(session->tls), GNUTLS_CRD_CERTIFICATE, session->cred);
 
 	no_action.sa_handler = SIG_IGN;
 	sigemptyset( & (no_action.sa_mask));
@@ -1215,9 +1311,8 @@ NuAuth* nu_client_init2(
 
 
 	/* SASL time */
-
-	/* initialize the sasl library */
 	ret = sasl_client_init(callbacks);
+	/* initialize the sasl library */
 	if (ret != SASL_OK) {
 		nu_exit_clean(session);
 		errno=EAGAIN;
@@ -1257,7 +1352,6 @@ NuAuth* nu_client_init2(
 	   sasl_setprop(conn, SASL_SEC_PROPS, &secprops); */
 
 	ret = mysasl_negotiate(*(session->tls), conn);
-	sasl_done();
 	if (ret != SASL_OK) {
 		nu_exit_clean(session);
 		errno=EACCES;
