@@ -195,37 +195,36 @@ int main(int argc,char * argv[])
 	int nuauth_number_loggers=NB_ACLCHECK;
 	char * nuauth_acl_check_module;
 	char * nuauth_user_check_module;
-	char * nuauth_user_logs_module;
-	char * nuauth_ip_authentication_module;
-confparams nuauth_vars[] = {
-	{ "nuauth_client_listen_addr" ,  G_TOKEN_STRING, 0 , g_strdup(AUTHREQ_CLIENT_LISTEN_ADDR) },
-	{ "nuauth_nufw_listen_addr" ,  G_TOKEN_STRING, 0 , g_strdup(AUTHREQ_NUFW_LISTEN_ADDR) },
-	{ "nuauth_gw_packet_port" , G_TOKEN_INT , AUTHREQ_PORT,NULL },
-	{ "nuauth_user_packet_port" , G_TOKEN_INT , USERPCKT_PORT ,NULL},
-	{ "nufw_gw_addr" , G_TOKEN_STRING , 0, GWSRV_ADDR },
-	{ "nuauth_packet_timeout" , G_TOKEN_INT , PACKET_TIMEOUT, NULL },
-	{ "nuauth_number_usercheckers" , G_TOKEN_INT , NB_USERCHECK, NULL},
-	{ "nuauth_number_aclcheckers" , G_TOKEN_INT , NB_ACLCHECK, NULL },
-	{ "nuauth_number_ipauthcheckers" , G_TOKEN_INT , NB_ACLCHECK, NULL },
-	{ "nuauth_number_loggers" , G_TOKEN_INT , NB_LOGGERS, NULL },
-	{ "nuauth_log_users" , G_TOKEN_INT , 1, NULL },
-	{ "nuauth_log_users_sync" , G_TOKEN_INT , 0, NULL },
-	{ "nuauth_log_users_strict" , G_TOKEN_INT , 1, NULL },
-	{ "nuauth_log_users_without_realm" , G_TOKEN_INT , 1, NULL },
-	{ "nuauth_user_check_module" , G_TOKEN_STRING , 1, g_strdup(DEFAULT_USERAUTH_MODULE) },
-	{ "nuauth_acl_check_module" , G_TOKEN_STRING , 1, g_strdup(DEFAULT_ACLS_MODULE) },
-	{ "nuauth_user_logs_module" , G_TOKEN_STRING , 1, g_strdup(DEFAULT_LOGS_MODULE) },
-	{ "nuauth_prio_to_nok" , G_TOKEN_INT , 1, NULL },
-	{ "nuauth_datas_persistance" , G_TOKEN_INT , 10, NULL },
-	{ "nuauth_aclcheck_state_ready" , G_TOKEN_INT , 1,NULL },
-	{ "nuauth_push_to_client" , G_TOKEN_INT , 1,NULL },
-	{ "nuauth_do_ip_authentication" , G_TOKEN_INT , 0,NULL },
-	{ "nuauth_ip_authentication_module" , G_TOKEN_STRING , 1, g_strdup(DEFAULT_IPAUTH_MODULE) },
-	{ "nuauth_multi_users" , G_TOKEN_STRING , 1, NULL },
-	{ "nuauth_multi_servers" , G_TOKEN_STRING , 1, NULL },
-	{ "nuauth_acl_cache" , G_TOKEN_INT , 0,NULL },
-	{ "nuauth_user_cache" , G_TOKEN_INT , 0,NULL },
-};
+    char * nuauth_user_logs_module;
+    char * nuauth_ip_authentication_module;
+    confparams nuauth_vars[] = {
+        { "nuauth_client_listen_addr" ,  G_TOKEN_STRING, 0 , AUTHREQ_CLIENT_LISTEN_ADDR },
+        { "nuauth_nufw_listen_addr" ,  G_TOKEN_STRING, 0 , AUTHREQ_NUFW_LISTEN_ADDR },
+        { "nuauth_gw_packet_port" , G_TOKEN_INT , AUTHREQ_PORT,NULL },
+        { "nuauth_push_to_client", G_TOKEN_INT, 1 , NULL},
+        { "nuauth_user_packet_port" , G_TOKEN_INT , USERPCKT_PORT ,NULL},
+        { "nufw_gw_addr" , G_TOKEN_STRING , 0, GWSRV_ADDR },
+        { "nuauth_packet_timeout" , G_TOKEN_INT , PACKET_TIMEOUT, NULL },
+        { "nuauth_number_usercheckers" , G_TOKEN_INT , NB_USERCHECK, NULL},
+        { "nuauth_number_aclcheckers" , G_TOKEN_INT , NB_ACLCHECK, NULL },
+        { "nuauth_number_ipauthcheckers" , G_TOKEN_INT , NB_ACLCHECK, NULL },
+        { "nuauth_number_loggers" , G_TOKEN_INT , NB_LOGGERS, NULL },
+        { "nuauth_log_users" , G_TOKEN_INT , 1, NULL },
+        { "nuauth_log_users_sync" , G_TOKEN_INT , 0, NULL },
+        { "nuauth_log_users_strict" , G_TOKEN_INT , 1, NULL },
+        { "nuauth_log_users_without_realm" , G_TOKEN_INT , 1, NULL },
+        { "nuauth_user_check_module" , G_TOKEN_STRING , 1, DEFAULT_USERAUTH_MODULE },
+        { "nuauth_acl_check_module" , G_TOKEN_STRING , 1, DEFAULT_ACLS_MODULE },
+        { "nuauth_user_logs_module" , G_TOKEN_STRING , 1, DEFAULT_LOGS_MODULE },
+        { "nuauth_prio_to_nok" , G_TOKEN_INT , 1, NULL },
+        { "nuauth_datas_persistance" , G_TOKEN_INT , 10, NULL },
+        { "nuauth_do_ip_authentication" , G_TOKEN_INT , 0,NULL },
+        { "nuauth_ip_authentication_module" , G_TOKEN_STRING , 1, DEFAULT_IPAUTH_MODULE },
+        { "nuauth_multi_users" , G_TOKEN_STRING , 1, NULL },
+        { "nuauth_multi_servers" , G_TOKEN_STRING , 1, NULL },
+        { "nuauth_acl_cache" , G_TOKEN_INT , 0,NULL },
+        { "nuauth_user_cache" , G_TOKEN_INT , 0,NULL },
+    };
 	tracking empty_header;
 	gpointer vpointer;
 	pid_t pidf;
@@ -346,12 +345,8 @@ confparams nuauth_vars[] = {
 	vpointer=get_confvar_value(nuauth_vars,sizeof(nuauth_vars)/sizeof(confparams),"nuauth_datas_persistance");
 	nuauth_datas_persistance=*(int*)(vpointer);//?vpointer:&nuauth_datas_persistance);
 
-	nuauth_aclcheck_state_ready=1;
-	vpointer=get_confvar_value(nuauth_vars,sizeof(nuauth_vars)/sizeof(confparams),"nuauth_aclcheck_state_ready");
-	nuauth_aclcheck_state_ready=*(int*)(vpointer);//?vpointer:&nuauth_aclcheck_state_ready);
-
 	vpointer=get_confvar_value(nuauth_vars,sizeof(nuauth_vars)/sizeof(confparams),"nuauth_push_to_client");
-	nuauth_push=*(int*)(vpointer);//?vpointer:&nuauth_push);
+	nuauth_push=*(int*)(vpointer);
 
 	vpointer=get_confvar_value(nuauth_vars,sizeof(nuauth_vars)/sizeof(confparams),"nuauth_do_ip_authentication");
 	nuauth_do_ip_authentication=*(int*)(vpointer);//?vpointer:&nuauth_do_ip_authentication);
@@ -627,11 +622,6 @@ confparams nuauth_vars[] = {
 	}
 
 
-	/* internal Use */
-	ALLGROUP=NULL;
-	ALLGROUP=g_slist_prepend(ALLGROUP, GINT_TO_POINTER(0) );
-
-
 	if (nuauth_acl_cache) {
 		GThread *acl_cache_thread;
 			/* create acl cache thread */
@@ -849,7 +839,7 @@ confparams nuauth_vars[] = {
 		exit(EXIT_FAILURE);
 	}
 	/* a little sleep */
-	usleep(500000);	
+    sleep(1);
 
 	/* admin task */
 	for(;;){
