@@ -163,7 +163,7 @@ static gchar* generate_appname(gchar *Name)
 	return g_strdup(Name);
 }
 
-G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
+G_MODULE_EXPORT gint user_packet_logs (connection* element, int state){
 	MYSQL *ld = g_private_get (mysql_priv);
 	char request[LONG_REQUEST_SIZE];
 	int Result;
@@ -179,8 +179,8 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 
 	/* contruct request */
 	switch (state) {
-		case STATE_OPEN:
-			switch ((element.tracking_hdrs).protocol){
+		case CONN_STATE_OPEN:
+			switch ((element->tracking_hdrs).protocol){
 				case IPPROTO_TCP:
 
 					//
@@ -213,10 +213,10 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 #endif
 						if (snprintf(request,SHORT_REQUEST_SIZE-1,"UPDATE %s SET state=%hu,end_timestamp=FROM_UNIXTIME(%lu) WHERE (ip_saddr=%lu  AND tcp_sport=%u AND (state=1 OR state=2))",
 									mysql_table_name,
-									STATE_CLOSE,
-									element.timestamp,
-									(long unsigned int)(element.tracking_hdrs).daddr,
-									(element.tracking_hdrs).source
+									CONN_STATE_CLOSE,
+									element->timestamp,
+									(long unsigned int)(element->tracking_hdrs).daddr,
+									(element->tracking_hdrs).source
 							    ) >= SHORT_REQUEST_SIZE-1){
 
 							if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
@@ -232,22 +232,22 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 						}
 					}
 
-					if (element.username != NULL) {
+					if (element->username != NULL) {
 						gchar* OSFullname;
 						gchar* AppFullname;
-						OSFullname = generate_osname(element.sysname,element.version,element.release);
-						AppFullname = generate_appname(element.appname); /*Just a size check actually*/
+						OSFullname = generate_osname(element->sysname,element->version,element->release);
+						AppFullname = generate_appname(element->appname); /*Just a size check actually*/
 						if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,tcp_sport,tcp_dport,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,%lu,%lu,%u,%u,%hu,'ACCEPT','%s','%s')",
 									mysql_table_name,
-									element.username,
-									(element.user_id),
-									element.timestamp,
-									(element.tracking_hdrs).protocol,
-									(long unsigned int)(element.tracking_hdrs).saddr,
-									(long unsigned int)(element.tracking_hdrs).daddr,
-									(element.tracking_hdrs).source,
-									(element.tracking_hdrs).dest,
-									STATE_OPEN,
+									element->username,
+									(element->user_id),
+									element->timestamp,
+									(element->tracking_hdrs).protocol,
+									(long unsigned int)(element->tracking_hdrs).saddr,
+									(long unsigned int)(element->tracking_hdrs).daddr,
+									(element->tracking_hdrs).source,
+									(element->tracking_hdrs).dest,
+									CONN_STATE_OPEN,
 									OSFullname,
 									AppFullname
 							    ) >= LONG_REQUEST_SIZE-1){
@@ -263,14 +263,14 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 					} else {
 						if (snprintf(request,SHORT_REQUEST_SIZE-1,"INSERT INTO %s (user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,tcp_sport,tcp_dport,state,oob_prefix) VALUES (%u,%lu,%u,%lu,%lu,%u,%u,%hu,'ACCEPT')",
 									mysql_table_name,
-									(element.user_id),
-									element.timestamp,
-									(element.tracking_hdrs).protocol,
-									(long unsigned int)(element.tracking_hdrs).saddr,
-									(long unsigned int)(element.tracking_hdrs).daddr,
-									(element.tracking_hdrs).source,
-									(element.tracking_hdrs).dest,
-									STATE_OPEN
+									(element->user_id),
+									element->timestamp,
+									(element->tracking_hdrs).protocol,
+									(long unsigned int)(element->tracking_hdrs).saddr,
+									(long unsigned int)(element->tracking_hdrs).daddr,
+									(element->tracking_hdrs).source,
+									(element->tracking_hdrs).dest,
+									CONN_STATE_OPEN
 							    ) >= SHORT_REQUEST_SIZE-1){
 							if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
 								g_warning("Building mysql insert query, the SHORT_REQUEST_SIZE limit was reached!\n");
@@ -289,19 +289,19 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 					{
 						gchar * OSFullname;
 						gchar * AppFullname;
-						OSFullname = generate_osname(element.sysname,element.version,element.release);
-						AppFullname = generate_appname(element.appname); /*Just a size check actually*/
+						OSFullname = generate_osname(element->sysname,element->version,element->release);
+						AppFullname = generate_appname(element->appname); /*Just a size check actually*/
 						if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,udp_sport,udp_dport,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,%lu,%lu,%u,%u,%hu,'ACCEPT','%s','%s')", //TODO : username NULL?
 									mysql_table_name,
-									element.username,
-									(element.user_id),
-									element.timestamp,
-									(element.tracking_hdrs).protocol,
-									(long unsigned int)(element.tracking_hdrs).saddr,
-									(long unsigned int)(element.tracking_hdrs).daddr,
-									(element.tracking_hdrs).source,
-									(element.tracking_hdrs).dest,
-									STATE_OPEN,
+									element->username,
+									(element->user_id),
+									element->timestamp,
+									(element->tracking_hdrs).protocol,
+									(long unsigned int)(element->tracking_hdrs).saddr,
+									(long unsigned int)(element->tracking_hdrs).daddr,
+									(element->tracking_hdrs).source,
+									(element->tracking_hdrs).dest,
+									CONN_STATE_OPEN,
 									OSFullname,
 									AppFullname
 							    ) >= LONG_REQUEST_SIZE-1){
@@ -327,18 +327,18 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 					{
 						gchar *OSFullname;
 						gchar *AppFullname;
-						OSFullname = generate_osname(element.sysname,element.version,element.release);
-						AppFullname = generate_appname(element.appname); /*Just a size check actually*/
+						OSFullname = generate_osname(element->sysname,element->version,element->release);
+						AppFullname = generate_appname(element->appname); /*Just a size check actually*/
 						if (snprintf(request,LONG_REQUEST_SIZE-1,
 									"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,%lu,%lu,%hu,'ACCEPT','%s','%s')", 
 									mysql_table_name,
-									element.username,
-									(element.user_id),
-									element.timestamp,
-									(element.tracking_hdrs).protocol,
-									(long unsigned int)(element.tracking_hdrs).saddr,
-									(long unsigned int)(element.tracking_hdrs).daddr,
-									STATE_OPEN,
+									element->username,
+									(element->user_id),
+									element->timestamp,
+									(element->tracking_hdrs).protocol,
+									(long unsigned int)(element->tracking_hdrs).saddr,
+									(long unsigned int)(element->tracking_hdrs).daddr,
+									CONN_STATE_OPEN,
 									OSFullname,
 									AppFullname
 							    ) >= (LONG_REQUEST_SIZE-1)){
@@ -361,21 +361,21 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 					}
 			}
 			break;
-		case STATE_ESTABLISHED: 
-			if ((element.tracking_hdrs).protocol == IPPROTO_TCP){
+		case CONN_STATE_ESTABLISHED: 
+			if ((element->tracking_hdrs).protocol == IPPROTO_TCP){
 				int update_status = 0;
 				while (update_status < 2){
 					update_status++;
 					if (snprintf(request,SHORT_REQUEST_SIZE-1,"UPDATE %s SET state=%hu,start_timestamp=FROM_UNIXTIME(%lu) WHERE (ip_daddr=%lu AND ip_saddr=%lu AND tcp_dport=%u AND tcp_sport=%u AND state=%hu)",
 
 								mysql_table_name,
-								STATE_ESTABLISHED,
-								element.timestamp,
-								(long unsigned int)(element.tracking_hdrs).saddr,
-								(long unsigned int)(element.tracking_hdrs).daddr,
-								(element.tracking_hdrs).source,
-								(element.tracking_hdrs).dest,
-								STATE_OPEN
+								CONN_STATE_ESTABLISHED,
+								element->timestamp,
+								(long unsigned int)(element->tracking_hdrs).saddr,
+								(long unsigned int)(element->tracking_hdrs).daddr,
+								(element->tracking_hdrs).source,
+								(element->tracking_hdrs).dest,
+								CONN_STATE_OPEN
 						    ) >= SHORT_REQUEST_SIZE-1){
 						if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
 							g_warning("Building mysql update query, the SHORT_REQUEST_SIZE limit was reached!\n");
@@ -403,21 +403,21 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 				return 0;
 			}
 			break;
-		case STATE_CLOSE: 
-			if ((element.tracking_hdrs).protocol == IPPROTO_TCP){
+		case CONN_STATE_CLOSE: 
+			if ((element->tracking_hdrs).protocol == IPPROTO_TCP){
 				int update_status = 0;
 				while (update_status < 2){
 					update_status++;
 					if (snprintf(request,SHORT_REQUEST_SIZE-1,"UPDATE %s SET end_timestamp=FROM_UNIXTIME(%lu), state=%hu WHERE (ip_saddr=%lu AND ip_daddr=%lu AND tcp_sport=%u AND tcp_dport=%u AND state=%hu)",
 
 								mysql_table_name,
-								element.timestamp,
-								STATE_CLOSE,
-								(long unsigned int)(element.tracking_hdrs).saddr,
-								(long unsigned int)(element.tracking_hdrs).daddr,
-								(element.tracking_hdrs).source,
-								(element.tracking_hdrs).dest,
-								STATE_ESTABLISHED
+								element->timestamp,
+								CONN_STATE_CLOSE,
+								(long unsigned int)(element->tracking_hdrs).saddr,
+								(long unsigned int)(element->tracking_hdrs).daddr,
+								(element->tracking_hdrs).source,
+								(element->tracking_hdrs).dest,
+								CONN_STATE_ESTABLISHED
 						    ) >= SHORT_REQUEST_SIZE-1){
 						if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
 							g_warning("Building mysql update query, the SHORT_REQUEST_SIZE limit was reached!\n");
@@ -445,27 +445,27 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 				return 0;
 			}
 			break;
-		case STATE_DROP:
-			switch ((element.tracking_hdrs).protocol){
+		case CONN_STATE_DROP:
+			switch ((element->tracking_hdrs).protocol){
 				case IPPROTO_TCP:
 					{
-						if (element.username){
+						if (element->username){
 							gchar *OSFullname;
 							gchar *AppFullname;
-							OSFullname = generate_osname(element.sysname,element.version,element.release);
-							AppFullname = generate_appname(element.appname); /*Just a size check actually*/
+							OSFullname = generate_osname(element->sysname,element->version,element->release);
+							AppFullname = generate_appname(element->appname); /*Just a size check actually*/
 							if (snprintf(request,LONG_REQUEST_SIZE-1,
 										"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,tcp_sport,tcp_dport,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,%lu,%lu,%u,%u,%hu,'DROP','%s','%s')", 
 										mysql_table_name,
-										element.username,
-										(element.user_id),
-										element.timestamp,
-										(element.tracking_hdrs).protocol,
-										(long unsigned int)(element.tracking_hdrs).saddr,
-										(long unsigned int)(element.tracking_hdrs).daddr,
-										(element.tracking_hdrs).source,
-										(element.tracking_hdrs).dest,
-										STATE_DROP,
+										element->username,
+										(element->user_id),
+										element->timestamp,
+										(element->tracking_hdrs).protocol,
+										(long unsigned int)(element->tracking_hdrs).saddr,
+										(long unsigned int)(element->tracking_hdrs).daddr,
+										(element->tracking_hdrs).source,
+										(element->tracking_hdrs).dest,
+										CONN_STATE_DROP,
 										OSFullname,
 										AppFullname
 								    ) >= LONG_REQUEST_SIZE-1){
@@ -487,13 +487,13 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 							if (snprintf(request,LONG_REQUEST_SIZE-1,
 										"INSERT INTO %s (oob_time_sec,ip_protocol,ip_saddr,ip_daddr,tcp_sport,tcp_dport,state,oob_prefix) VALUES (%lu,%u,%lu,%lu,%u,%u,%hu,'UNAUTHENTICATED DROP')", 
 										mysql_table_name,
-										element.timestamp,
-										(element.tracking_hdrs).protocol,
-										(long unsigned int)(element.tracking_hdrs).saddr,
-										(long unsigned int)(element.tracking_hdrs).daddr,
-										(element.tracking_hdrs).source,
-										(element.tracking_hdrs).dest,
-										STATE_DROP) >= (LONG_REQUEST_SIZE-1)){
+										element->timestamp,
+										(element->tracking_hdrs).protocol,
+										(long unsigned int)(element->tracking_hdrs).saddr,
+										(long unsigned int)(element->tracking_hdrs).daddr,
+										(element->tracking_hdrs).source,
+										(element->tracking_hdrs).dest,
+										CONN_STATE_DROP) >= (LONG_REQUEST_SIZE-1)){
 								if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
 									g_warning("Building mysql insert query, the LONG_REQUEST_SIZE limit was reached!\n");
 								return -1;
@@ -511,20 +511,20 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 					{
 						gchar* OSFullname;
 						gchar* AppFullname;
-						OSFullname = generate_osname(element.sysname,element.version,element.release);
-						AppFullname = generate_appname(element.appname); /*Just a size check actually*/
-						if (element.username){
+						OSFullname = generate_osname(element->sysname,element->version,element->release);
+						AppFullname = generate_appname(element->appname); /*Just a size check actually*/
+						if (element->username){
 							if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,udp_sport,udp_dport,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,%lu,%lu,%u,%u,%hu,'DROP','%s','%s')", 
 										mysql_table_name,
-										element.username,
-										(element.user_id),
-										element.timestamp,
-										(element.tracking_hdrs).protocol,
-										(long unsigned int)(element.tracking_hdrs).saddr,
-										(long unsigned int)(element.tracking_hdrs).daddr,
-										(element.tracking_hdrs).source,
-										(element.tracking_hdrs).dest,
-										STATE_DROP,
+										element->username,
+										(element->user_id),
+										element->timestamp,
+										(element->tracking_hdrs).protocol,
+										(long unsigned int)(element->tracking_hdrs).saddr,
+										(long unsigned int)(element->tracking_hdrs).daddr,
+										(element->tracking_hdrs).source,
+										(element->tracking_hdrs).dest,
+										CONN_STATE_DROP,
 										OSFullname,
 										AppFullname
 								    ) >= LONG_REQUEST_SIZE-1){
@@ -549,13 +549,13 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 							if (snprintf(request,LONG_REQUEST_SIZE-1,
 										"INSERT INTO %s (oob_time_sec,ip_protocol,ip_saddr,ip_daddr,udp_sport,udp_dport,state,oob_prefix) VALUES (%lu,%u,%lu,%lu,%u,%u,%hu,'UNAUTHENTICATED DROP')", 
 										mysql_table_name,
-										element.timestamp,
-										(element.tracking_hdrs).protocol,
-										(long unsigned int)(element.tracking_hdrs).saddr,
-										(long unsigned int)(element.tracking_hdrs).daddr,
-										(element.tracking_hdrs).source,
-										(element.tracking_hdrs).dest,
-										STATE_DROP) >= (LONG_REQUEST_SIZE-1)){
+										element->timestamp,
+										(element->tracking_hdrs).protocol,
+										(long unsigned int)(element->tracking_hdrs).saddr,
+										(long unsigned int)(element->tracking_hdrs).daddr,
+										(element->tracking_hdrs).source,
+										(element->tracking_hdrs).dest,
+										CONN_STATE_DROP) >= (LONG_REQUEST_SIZE-1)){
 								if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
 									g_warning("Building mysql insert query, the LONG_REQUEST_SIZE limit was reached!\n");
 								return -1;
@@ -573,17 +573,17 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 					{
 						gchar* OSFullname;
 						gchar* AppFullname;
-						OSFullname = generate_osname(element.sysname,element.version,element.release);
-						AppFullname = generate_appname(element.appname); /*Just a size check actually*/
+						OSFullname = generate_osname(element->sysname,element->version,element->release);
+						AppFullname = generate_appname(element->appname); /*Just a size check actually*/
 						if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,%lu,%lu,%hu,'DROP','%s','%s')", //TODO : username NULL?
 									mysql_table_name,
-									element.username,
-									(element.user_id),
-									element.timestamp,
-									(element.tracking_hdrs).protocol,
-									(long unsigned int) (element.tracking_hdrs).saddr,
-									(long unsigned int) (element.tracking_hdrs).daddr,
-									STATE_DROP,
+									element->username,
+									(element->user_id),
+									element->timestamp,
+									(element->tracking_hdrs).protocol,
+									(long unsigned int) (element->tracking_hdrs).saddr,
+									(long unsigned int) (element->tracking_hdrs).daddr,
+									CONN_STATE_DROP,
 									OSFullname,
 									AppFullname
 							    ) >= LONG_REQUEST_SIZE-1){
