@@ -99,22 +99,22 @@ G_MODULE_EXPORT PGconn *pgsql_conn_init(void){
     PGconn *ld = NULL;
     char *pgsql_conninfo;
     int pgsql_status; //,err,version=3;
-    char port[15],timeout[15],server_port[15];
+    char port[15],timeout[15]; //,server_port[15];
 
     if (snprintf(port,14,"%d",pgsql_server_port) >= 14){return NULL;}
     if (snprintf(timeout,14,"%d",pgsql_request_timeout) >= 14){return NULL;};
-    if (snprintf(server_port,14,"%d",pgsql_server_port) >= 14){return NULL;};
+//    if (snprintf(server_port,14,"%d",pgsql_server_port) >= 14){return NULL;};
     pgsql_conninfo = (char *)calloc(strlen(pgsql_user) + strlen(pgsql_passwd) + 
-        strlen(pgsql_server) + strlen(pgsql_ssl) + strlen(server_port) + strlen(pgsql_db_name) +
+        strlen(pgsql_server) + strlen(pgsql_ssl) + strlen(pgsql_db_name) +
         strlen(port) + strlen(timeout) +
         strlen("hostaddr='' port= dbname='' user='' password='' connect_timeout= sslmode='' ") + 1, 
-        sizeof(char));
+        sizeof(char)); //reminder : sslmode is unused for now
     if (pgsql_conninfo == NULL){return NULL;}
     //Build string we will pass to PQconnectdb
     strncat(pgsql_conninfo,"host='",6);
     strncat(pgsql_conninfo,pgsql_server,strlen(pgsql_server));
     strncat(pgsql_conninfo,"' port=",7);
-    strncat(pgsql_conninfo,port,strlen(pgsql_conninfo));
+    strncat(pgsql_conninfo,port,strlen(port));
     strncat(pgsql_conninfo," dbname='",9);
     strncat(pgsql_conninfo,pgsql_db_name,strlen(pgsql_db_name));
     strncat(pgsql_conninfo,"' user='",8);
@@ -133,7 +133,8 @@ G_MODULE_EXPORT PGconn *pgsql_conn_init(void){
 		    " dbname='", pgsql_db_name,
 		    "' user='",pgsql_user,
 		    "' password='",pgsql_passwd,
-		    "' connect_timeout=",timeout);
+		    "' connect_timeout=",timeout,
+                    NULL);
 #endif
 		    
     if (DEBUG_OR_NOT(DEBUG_LEVEL_DEBUG,DEBUG_AREA_MAIN))
@@ -160,14 +161,15 @@ G_MODULE_EXPORT PGconn *pgsql_conn_init(void){
     return ld;
 }
 
-static gchar * generate_osname(gchar *Name,gchar *Version,gchar *Release)
+static gchar * generate_osname(gchar *Name, gchar *Version, gchar *Release)
 {
-  if (Name && Release && Version){
+  if (Name && Release && Version) {
     if ((strlen(Name)+strlen(Release)+strlen(Version)+3) > OSNAME_MAX_SIZE)
       return g_strdup("");
-  }else
+  } else
       return g_strdup("");
-  return g_strjoin("-",Name,Version,Release);
+  
+  return g_strjoin("-", Name, Version, Release, NULL);
 }
 
 static gchar* generate_appname(gchar *Name)
@@ -183,7 +185,8 @@ static gchar* generate_appname(gchar *Name)
 
 
 
-G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
+G_MODULE_EXPORT gint user_packet_logs (connection* element, int state)
+{
     PGconn *ld = g_private_get (pgsql_priv);
     char request[LONG_REQUEST_SIZE];
     struct in_addr ipone,iptwo;
@@ -200,8 +203,8 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
     }
     /* contruct request */
     switch (state){
-      case STATE_OPEN:
-        switch ((element.tracking_hdrs).protocol){
+      case CONN_STATE_OPEN:
+        switch ((element->tracking_hdrs).protocol){
           case IPPROTO_TCP:
             //
             // FIELD          IN NUAUTH STRUCTURE               IN ULOG
@@ -220,15 +223,17 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
             //
             //
             //
-            ipone.s_addr=ntohl((element.tracking_hdrs).saddr);
-            strncpy(tmp_inet1,inet_ntoa(ipone),40) ;
+            ipone.s_addr=ntohl((element->tracking_hdrs).saddr);
+            iptwo.s_addr=ntohl((element->tracking_hdrs).daddr);
+            strncpy(tmp_inet1,inet_ntoa(ipone),40);
+            strncpy(tmp_inet2,inet_ntoa(iptwo),40);
             if (nuauth_log_users_strict){
                 if (snprintf(request,SHORT_REQUEST_SIZE-1,"UPDATE %s SET end_timestamp=%lu, state=%hu WHERE (ip_saddr='%s' and tcp_sport=%u and (state=1 or state=2))",
                   pgsql_table_name,
-                  element.timestamp,
-                  STATE_CLOSE,
+                  element->timestamp,
+                  CONN_STATE_CLOSE,
                   tmp_inet1,
-                  (element.tracking_hdrs).source
+                  (element->tracking_hdrs).source
                   ) >= SHORT_REQUEST_SIZE-1){
                 if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
                     g_warning("Building pgsql update query, the SHORT_REQUEST_SIZE limit was reached!\n");
@@ -244,22 +249,22 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 		PQclear(Result);
 	      }
             }
-	    if (element.username != NULL) { 
+            if (element->username != NULL) {
                 gchar* OSFullname;
                 gchar* AppFullname;
-                OSFullname = generate_osname(element.sysname,element.version,element.release);
-                AppFullname = generate_appname(element.appname); /*Just a size check actually*/
+                OSFullname = generate_osname(element->sysname,element->version,element->release);
+                AppFullname = generate_appname(element->appname); /*Just a size check actually*/
                 if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,tcp_sport,tcp_dport,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,'%s','%s',%u,%u,%hu,'ACCEPT','%s','%s');",
                   pgsql_table_name,
-                  element.username,
-                  (element.user_id),
-                  element.timestamp,
-                  (element.tracking_hdrs).protocol,
+                  element->username,
+                  (element->user_id),
+                  element->timestamp,
+                  (element->tracking_hdrs).protocol,
                   tmp_inet1,
                   tmp_inet2,
-                  (element.tracking_hdrs).source,
-                  (element.tracking_hdrs).dest,
-                  STATE_OPEN,
+                  (element->tracking_hdrs).source,
+                  (element->tracking_hdrs).dest,
+                  CONN_STATE_OPEN,
                   OSFullname,
                   AppFullname
                   ) >= LONG_REQUEST_SIZE-1 ) {
@@ -274,14 +279,14 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
 	    } else {
               if (snprintf(request,SHORT_REQUEST_SIZE-1,"INSERT INTO %s (user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,tcp_sport,tcp_dport,state,oob_prefix) VALUES (%u,%lu,%u,'%s','%s',%u,%u,%hu,'ACCEPT');", 
                   pgsql_table_name,
-                  (element.user_id),
-                  element.timestamp,
-                  (element.tracking_hdrs).protocol,
+                  (element->user_id),
+                  element->timestamp,
+                  (element->tracking_hdrs).protocol,
                   tmp_inet1,
                   tmp_inet2,
-                  (element.tracking_hdrs).source,
-                  (element.tracking_hdrs).dest,
-                  STATE_OPEN
+                  (element->tracking_hdrs).source,
+                  (element->tracking_hdrs).dest,
+                  CONN_STATE_OPEN
                   ) >= SHORT_REQUEST_SIZE-1){
                 if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
                     g_warning("Building pgsql insert query, the SHORT_REQUEST_SIZE limit was reached!\n");
@@ -310,23 +315,23 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
           {
             gchar* OSFullname;
             gchar* AppFullname;
-            OSFullname = generate_osname(element.sysname,element.version,element.release);
-            AppFullname = generate_appname(element.appname); /*Just a size check actually*/
-            ipone.s_addr=ntohl((element.tracking_hdrs).saddr);
-            iptwo.s_addr=ntohl((element.tracking_hdrs).daddr);
+            OSFullname = generate_osname(element->sysname,element->version,element->release);
+            AppFullname = generate_appname(element->appname); /*Just a size check actually*/
+            ipone.s_addr=ntohl((element->tracking_hdrs).saddr);
+            iptwo.s_addr=ntohl((element->tracking_hdrs).daddr);
             strncpy(tmp_inet1,inet_ntoa(ipone),40) ;
             strncpy(tmp_inet2,inet_ntoa(iptwo),40) ;
             if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,udp_sport,udp_dport,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,'%s','%s',%u,%u,%hu,'ACCEPT','%s','%s');", //TODO : Add a check about username being NULL
                   pgsql_table_name,
-                  element.username,
-                  (element.user_id),
-                  element.timestamp,
-                  (element.tracking_hdrs).protocol,
+                  element->username,
+                  (element->user_id),
+                  element->timestamp,
+                  (element->tracking_hdrs).protocol,
                   tmp_inet1,
                   tmp_inet2,
-                  (element.tracking_hdrs).source,
-                  (element.tracking_hdrs).dest,
-                  STATE_OPEN,
+                  (element->tracking_hdrs).source,
+                  (element->tracking_hdrs).dest,
+                  CONN_STATE_OPEN,
                   OSFullname,
                   AppFullname
                   ) >= LONG_REQUEST_SIZE-1 ){
@@ -352,21 +357,21 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
           {
             gchar* OSFullname;
             gchar* AppFullname;
-            OSFullname = generate_osname(element.sysname,element.version,element.release);
-            AppFullname = generate_appname(element.appname); /*Just a size check actually*/
-            ipone.s_addr=ntohl((element.tracking_hdrs).saddr);
-            iptwo.s_addr=ntohl((element.tracking_hdrs).daddr);
+            OSFullname = generate_osname(element->sysname,element->version,element->release);
+            AppFullname = generate_appname(element->appname); /*Just a size check actually*/
+            ipone.s_addr=ntohl((element->tracking_hdrs).saddr);
+            iptwo.s_addr=ntohl((element->tracking_hdrs).daddr);
             strncpy(tmp_inet1,inet_ntoa(ipone),40) ;
             strncpy(tmp_inet2,inet_ntoa(iptwo),40) ;
             if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,'%s','%s',%hu,'ACCEPT','%s','%s');", //TODO : username NULL?
                   pgsql_table_name,
-                  element.username,
-                  (element.user_id),
-                  element.timestamp,
-                  (element.tracking_hdrs).protocol,
+                  element->username,
+                  (element->user_id),
+                  element->timestamp,
+                  (element->tracking_hdrs).protocol,
                   tmp_inet1,
                   tmp_inet2,
-                  STATE_OPEN,
+                  CONN_STATE_OPEN,
                   OSFullname,
                   AppFullname
                   ) >= LONG_REQUEST_SIZE-1){
@@ -390,24 +395,24 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
           }
         }
         break;
-      case STATE_ESTABLISHED:
-        if ((element.tracking_hdrs).protocol == IPPROTO_TCP){
+      case CONN_STATE_ESTABLISHED:
+        if ((element->tracking_hdrs).protocol == IPPROTO_TCP){
             int update_status = 0;
             while (update_status < 2){
               update_status++;
-              ipone.s_addr=ntohl((element.tracking_hdrs).saddr);
-              iptwo.s_addr=ntohl((element.tracking_hdrs).daddr);
+              ipone.s_addr=ntohl((element->tracking_hdrs).saddr);
+              iptwo.s_addr=ntohl((element->tracking_hdrs).daddr);
               strncpy(tmp_inet1,inet_ntoa(ipone),40) ;
               strncpy(tmp_inet2,inet_ntoa(iptwo),40) ;
               if (snprintf(request,SHORT_REQUEST_SIZE-1,"UPDATE %s SET state=%hu, start_timestamp=%lu WHERE (ip_daddr='%s' and ip_saddr='%s' and tcp_dport=%u and tcp_sport=%u and state=%hu);",
                   pgsql_table_name,
-                  STATE_ESTABLISHED,
-                  element.timestamp,
+                  CONN_STATE_ESTABLISHED,
+                  element->timestamp,
                   tmp_inet1,
                   tmp_inet2,
-                  (element.tracking_hdrs).source,
-                  (element.tracking_hdrs).dest,
-                  STATE_OPEN
+                  (element->tracking_hdrs).source,
+                  (element->tracking_hdrs).dest,
+                  CONN_STATE_OPEN
                   ) >= SHORT_REQUEST_SIZE-1){
                 if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
                     g_warning("Building pgsql update query, the SHORT_REQUEST_SIZE limit was reached!\n");
@@ -439,24 +444,24 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
         }
         //Nothing will be done...
         return 0;
-      case STATE_CLOSE:
-        if ((element.tracking_hdrs).protocol == IPPROTO_TCP){
+      case CONN_STATE_CLOSE:
+        if ((element->tracking_hdrs).protocol == IPPROTO_TCP){
             int update_status = 0;
             while (update_status < 2){
               update_status++;
-              ipone.s_addr=ntohl((element.tracking_hdrs).saddr);
-              iptwo.s_addr=ntohl((element.tracking_hdrs).daddr);
+              ipone.s_addr=ntohl((element->tracking_hdrs).saddr);
+              iptwo.s_addr=ntohl((element->tracking_hdrs).daddr);
               strncpy(tmp_inet1,inet_ntoa(ipone),40) ;
               strncpy(tmp_inet2,inet_ntoa(iptwo),40) ;
               if (snprintf(request,SHORT_REQUEST_SIZE-1,"UPDATE %s SET end_timestamp=%lu, state=%hu WHERE (ip_saddr='%s' and ip_daddr='%s' and tcp_sport=%u and tcp_dport=%u and state=%hu);",
                   pgsql_table_name,
-                  element.timestamp,
-                  STATE_CLOSE,
+                  element->timestamp,
+                  CONN_STATE_CLOSE,
                   tmp_inet1,
                   tmp_inet2,
-                  (element.tracking_hdrs).source,
-                  (element.tracking_hdrs).dest,
-                  STATE_ESTABLISHED
+                  (element->tracking_hdrs).source,
+                  (element->tracking_hdrs).dest,
+                  CONN_STATE_ESTABLISHED
                   ) >= SHORT_REQUEST_SIZE-1){
                 if (DEBUG_OR_NOT(DEBUG_LEVEL_SERIOUS_WARNING,DEBUG_AREA_MAIN))
                     g_warning("Building pgsql update query, the SHORT_REQUEST_SIZE limit was reached!\n");
@@ -489,32 +494,32 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
         }
         //Nothing will be done...
         return 0;
-      case STATE_DROP:
-        switch ((element.tracking_hdrs).protocol) {
+      case CONN_STATE_DROP:
+        switch ((element->tracking_hdrs).protocol) {
           case IPPROTO_TCP:
           {
             gchar* OSFullname;
             gchar* AppFullname;
-            OSFullname = generate_osname(element.sysname,element.version,element.release);
-            AppFullname = generate_appname(element.appname); /*Just a size check actually*/
-            ipone.s_addr=ntohl((element.tracking_hdrs).saddr);
-            iptwo.s_addr=ntohl((element.tracking_hdrs).daddr);
+            OSFullname = generate_osname(element->sysname,element->version,element->release);
+            AppFullname = generate_appname(element->appname); /*Just a size check actually*/
+            ipone.s_addr=ntohl((element->tracking_hdrs).saddr);
+            iptwo.s_addr=ntohl((element->tracking_hdrs).daddr);
             strncpy(tmp_inet1,inet_ntoa(ipone),40) ;
             strncpy(tmp_inet2,inet_ntoa(iptwo),40) ;
-	    if (element.username == NULL){
-			element.username="No User Given";
+	    if (element->username == NULL){
+			element->username="No User Given";
 	    }
             if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,tcp_sport,tcp_dport,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,'%s','%s',%u,%u,%hu,'DROP','%s','%s');",//TODO : username NULL?
                   pgsql_table_name,
-                  element.username,
-                  (element.user_id),
-                  element.timestamp,
-                  (element.tracking_hdrs).protocol,
+                  element->username,
+                  (element->user_id),
+                  element->timestamp,
+                  (element->tracking_hdrs).protocol,
                   tmp_inet1,
                   tmp_inet2,
-                  (element.tracking_hdrs).source,
-                  (element.tracking_hdrs).dest,
-                  STATE_DROP,
+                  (element->tracking_hdrs).source,
+                  (element->tracking_hdrs).dest,
+                  CONN_STATE_DROP,
                   OSFullname,
                   AppFullname
                   ) >= LONG_REQUEST_SIZE-1 ){
@@ -540,26 +545,26 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
           {
             gchar* OSFullname;
             gchar* AppFullname;
-            OSFullname = generate_osname(element.sysname,element.version,element.release);
-            AppFullname = generate_appname(element.appname); /*Just a size check actually*/
-            ipone.s_addr=ntohl((element.tracking_hdrs).saddr);
-            iptwo.s_addr=ntohl((element.tracking_hdrs).daddr);
+            OSFullname = generate_osname(element->sysname,element->version,element->release);
+            AppFullname = generate_appname(element->appname); /*Just a size check actually*/
+            ipone.s_addr=ntohl((element->tracking_hdrs).saddr);
+            iptwo.s_addr=ntohl((element->tracking_hdrs).daddr);
             strncpy(tmp_inet1,inet_ntoa(ipone),40) ;
             strncpy(tmp_inet2,inet_ntoa(iptwo),40) ;
-	    if (element.username == NULL){
-			element.username="No User Given";
+	    if (element->username == NULL){
+			element->username="No User Given";
 	    }
             if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,udp_sport,udp_dport,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,'%s','%s',%u,%u,%hu,'DROP','%s','%s');", //TODO : username NULL?
                   pgsql_table_name,
-                  element.username,
-                  (element.user_id),
-                  element.timestamp,
-                  (element.tracking_hdrs).protocol,
+                  element->username,
+                  (element->user_id),
+                  element->timestamp,
+                  (element->tracking_hdrs).protocol,
                   tmp_inet1,
                   tmp_inet2,
-                  (element.tracking_hdrs).source,
-                  (element.tracking_hdrs).dest,
-                  STATE_DROP,
+                  (element->tracking_hdrs).source,
+                  (element->tracking_hdrs).dest,
+                  CONN_STATE_DROP,
                   OSFullname,
                   AppFullname
                   ) >= LONG_REQUEST_SIZE-1 ){
@@ -586,22 +591,22 @@ G_MODULE_EXPORT gint user_packet_logs (connection element, int state){
           {
             gchar* OSFullname;
             gchar* AppFullname;
-            OSFullname = generate_osname(element.sysname,element.version,element.release);
-            AppFullname = generate_appname(element.appname); /*Just a size check actually*/
-            ipone.s_addr=ntohl((element.tracking_hdrs).saddr);
-            iptwo.s_addr=ntohl((element.tracking_hdrs).daddr);
+            OSFullname = generate_osname(element->sysname,element->version,element->release);
+            AppFullname = generate_appname(element->appname); /*Just a size check actually*/
+            ipone.s_addr=ntohl((element->tracking_hdrs).saddr);
+            iptwo.s_addr=ntohl((element->tracking_hdrs).daddr);
             strncpy(tmp_inet1,inet_ntoa(ipone),40) ;
             strncpy(tmp_inet2,inet_ntoa(iptwo),40) ;
             if (snprintf(request,LONG_REQUEST_SIZE-1,"INSERT INTO %s (username,user_id,oob_time_sec,ip_protocol,ip_saddr,ip_daddr,state,oob_prefix,client_os,client_app) VALUES ('%s',%u,%lu,%u,'%s','%s',%lu,%hu,'DROP','%s','%s');", //TODO : username NULL?
                   pgsql_table_name,
-                  element.username,
-                  (element.user_id),
-                  element.timestamp,
-                  (element.tracking_hdrs).protocol,
+                  element->username,
+                  (element->user_id),
+                  element->timestamp,
+                  (element->tracking_hdrs).protocol,
                   tmp_inet1,
                   tmp_inet2,
-                  element.timestamp,
-                  STATE_DROP,
+                  element->timestamp,
+                  CONN_STATE_DROP,
                   OSFullname,
                   AppFullname
                   ) >= LONG_REQUEST_SIZE-1){
