@@ -709,7 +709,6 @@ G_MODULE_EXPORT gchar* g_module_unload(void)
                       g_free(((struct T_app*)p_app->data)->appmd5);
               }
               g_slist_free(p_acl->apps);
-              g_free(p_acl);
           }
           // Free Src IPs
           if (p_acl->src_ip)
@@ -723,6 +722,7 @@ G_MODULE_EXPORT gchar* g_module_unload(void)
           // Free Dst ports
           if (p_acl->dst_ports)
               g_slist_free(p_acl->dst_ports);
+          g_free(p_acl);
       }
       // Now we can free the list
       g_slist_free(plaintext_acllist);
@@ -787,7 +787,10 @@ G_MODULE_EXPORT int user_check(const char *username, const char *clientpass,
   char *realpass;
   int initstatus;
   char *user;
-
+  static GStaticMutex plaintext_initmutex = G_STATIC_MUTEX_INIT;
+ 
+  /* init has only to be done once */
+  g_static_mutex_lock (&plaintext_initmutex);
   // Initialization if the user list is empty
   if (!plaintext_userlist) {
       initstatus = read_user_list();
@@ -797,6 +800,7 @@ G_MODULE_EXPORT int user_check(const char *username, const char *clientpass,
           return SASL_BADAUTH;
       }
   }
+  g_static_mutex_unlock (&plaintext_initmutex);
 
   /* strip username from domain */
   user = get_rid_of_domain((char*)username);
@@ -856,7 +860,11 @@ G_MODULE_EXPORT GSList* acl_check(connection* element)
   struct T_plaintext_acl *p_acl;
   int initstatus;
   uint32_t src_ip, dst_ip;
+  static GStaticMutex plaintext_initmutex = G_STATIC_MUTEX_INIT;
 
+
+  /* init has only to be done once */
+  g_static_mutex_lock (&plaintext_initmutex);
   // Initialization if the ACL list is empty
   if (!plaintext_acllist) {
       initstatus = read_acl_list();
@@ -866,6 +874,7 @@ G_MODULE_EXPORT GSList* acl_check(connection* element)
           return NULL;
       }
   }
+  g_static_mutex_unlock (&plaintext_initmutex);
 
   // netdata.protocol   // IPPROTO_TCP || IPPROTO_UDP || IPPROTO_ICMP
   // netdata.type       // for ICMP
