@@ -1,5 +1,5 @@
 /*
- * Copyright(C) 2004-2005 INL http://www.inl.fr/
+ * Copyright(C) 2004-2006 INL http://www.inl.fr/
  ** written by  Eric Leblond <regit@inl.fr>
  **             Vincent Deffontaines <vincent@inl.fr>
  **
@@ -38,28 +38,42 @@ void user_check_and_decide (gpointer userdata, gpointer data)
 {
 	connection * conn_elt=NULL;
 #ifdef DEBUG_ENABLE
-	if (DEBUG_OR_NOT(DEBUG_LEVEL_VERBOSE_DEBUG,DEBUG_AREA_USER))
-		g_message("entering user_check\n");
+        if (DEBUG_OR_NOT(DEBUG_LEVEL_VERBOSE_DEBUG,DEBUG_AREA_USER))
+            g_message("entering user_check\n");
 #endif
-	conn_elt = userpckt_decode(userdata);
-	/* if OK search and fill */
-	if ( conn_elt != NULL ) {
+        conn_elt = userpckt_decode(userdata);
+        /* if OK search and fill */
+        if ( conn_elt != NULL ) {
+            /* check source IP equality */
+            if  (  ((struct buffer_read *)userdata)->addr ==
+                    htonl(conn_elt->tracking_hdrs.saddr) ){
+
 #ifdef DEBUG_ENABLE
-		if (DEBUG_OR_NOT(DEBUG_LEVEL_DEBUG,DEBUG_AREA_PACKET)){
-			g_message("User : %s",conn_elt->username);
-			print_connection(conn_elt,NULL);
-		}
+                if (DEBUG_OR_NOT(DEBUG_LEVEL_DEBUG,DEBUG_AREA_PACKET)){
+                    g_message("User : %s",conn_elt->username);
+                    print_connection(conn_elt,NULL);
+                }
 #endif
-		g_async_queue_push (connexions_queue,conn_elt);
-		/* free userdata, packet is parsed now */
-		g_free(((struct buffer_read *)userdata)->buf);
-		g_free(userdata);
-	}
-	else {
-		if (DEBUG_OR_NOT(DEBUG_LEVEL_INFO,DEBUG_AREA_USER)){
-			g_message("User packet decoding failed\n");
-		}
-	}
+                g_async_queue_push (connexions_queue,conn_elt);
+            } else {
+                if (DEBUG_OR_NOT(DEBUG_LEVEL_INFO,DEBUG_AREA_USER)){
+                    struct in_addr badaddr;
+                    badaddr.s_addr=((struct buffer_read *)userdata)->addr;
+                    g_message("User %s on %s tried to authenticate packet from other ip\n",conn_elt->username,inet_ntoa(badaddr));
+                    print_connection(conn_elt,NULL);
+                }
+                /* free connection */
+                free_connection(conn_elt);
+            }
+            /* free userdata, packet is parsed now */
+            g_free(((struct buffer_read *)userdata)->buf);
+            g_free(userdata);
+        }
+        else {
+            if (DEBUG_OR_NOT(DEBUG_LEVEL_INFO,DEBUG_AREA_USER)){
+                g_message("User packet decoding failed\n");
+            }
+        }
 #ifdef DEBUG_ENABLE
 	if (DEBUG_OR_NOT(DEBUG_LEVEL_VERBOSE_DEBUG,DEBUG_AREA_USER))
 		g_message("leaving user_check\n");
@@ -360,6 +374,7 @@ static connection * userpckt_decode(struct buffer_read * datas)
 							}
 							connexion->user_id=datas->uid;
 							connexion->user_groups = datas->groups;
+							datas->groups = NULL;
 							connexion->sysname=datas->sysname;
 							connexion->release=datas->release;
 							connexion->version=datas->version;
