@@ -90,15 +90,15 @@ void* authsrv(){
 					}
 #endif
 					pthread_mutex_lock(session_active_mutex);
-				        if (tls.active){ //GRYZOR_ASKS : this is useless, see if () line 77
-						tls.active=0; //GRYZOR_ASKS : is there not a lock problem on this variable? it is used elsewhere with no lock
-						//gnutls_bye(*tls.session,GNUTLS_SHUT_WR);
+				        if (tls.active){ 
+						tls.active=0; 
 						socket_tls=(int)gnutls_transport_get_ptr(*tls.session);
+						gnutls_bye(*tls.session,GNUTLS_SHUT_WR);
 						shutdown(socket_tls,SHUT_RDWR);
+						close(socket_tls);
+						gnutls_deinit(*tls.session);
 					}
 					pthread_mutex_unlock(session_active_mutex);
-					gnutls_deinit(*tls.session);
-                                        //GRYZOR ASKS : could we add here : if (tls.session) ?
 					free(tls.session);
 					tls.session=NULL;
 					pthread_cond_signal(session_destroyed_cond);
