@@ -39,11 +39,16 @@ void nufw_cleanup( int signal ) {
     ipq_destroy_handle(hndl);
     /* destroy pid file */
     unlink(NUFW_PID_FILE);
+    /* destroy mutex */
+    pthread_mutex_destroy(&packets_list_mutex);
+    pthread_mutex_destroy(session_destroyed_mutex);
+    pthread_mutex_destroy(session_active_mutex);
     /* exit */
     exit(0);
 }
 
-int main(int argc,char * argv[]){
+int main(int argc,char * argv[])
+{
     pthread_t pckt_server,auth_server;
     struct hostent *authreq_srv, *listenaddr_srv;
     /* option */
